@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Parameter::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Parameter::VERSION    = '2.007_010';
+	$Type::Params::Parameter::VERSION    = '2.009_000';
 }
 
 $Type::Params::Parameter::VERSION =~ tr/_//d;
@@ -81,7 +81,7 @@ sub optional  {
 		: do {
 			$_[0]{optional} = $_[0]->has_default || grep(
 				$_->{uniq} == Optional->{uniq},
-				$_[0]->type->parents,
+				$_[0]->type, $_[0]->type->parents,
 			);
 		}
 }
@@ -173,6 +173,10 @@ sub _make_code {
 		&& $constraint->parent
 		&& $constraint->parent->{uniq} eq Optional->{uniq}
 		&& $constraint->type_parameter;
+	
+	# Allow Optional itself, without any parameter.
+	$really_optional = Types::Standard::Any
+		if $constraint && $constraint->{uniq} eq Optional->{uniq};
 
 	my $strictness;
 	if ( $self->has_strictness ) {
@@ -350,6 +354,9 @@ sub _make_code {
 	elsif ( $constraint->{uniq} == Any->{uniq} ) {
 		$coderef->add_line( '1; # ... nothing to do' );
 	}
+	elsif ( $args{is_slurpy} and $self->_dont_validate_slurpy ) {
+		$coderef->add_line( '1; # ... nothing to do' );
+	}
 	elsif ( $constraint->can_be_inlined ) {
 		$coderef->add_line( $strictness_test . sprintf(
 			"%s\n\tor %s;",
@@ -424,6 +431,28 @@ sub _make_code {
 	$self;
 }
 
+# This list can be reused safely.
+my @uniqs;
+
+# If $SLURPY is one of a handful of very loose type constraints, there is
+# no need to validate it because we built it as a hashref or arrayref ourself,
+# so there's no way it couldn't be a hashref or arrayref.
+sub _dont_validate_slurpy {
+	my $self = shift;
+	my $type = $self->type or return 1;
+	if ( not @uniqs ) {
+		@uniqs = map { $_->{uniq} }
+			Slurpy,
+			Slurpy[Any],      Any,
+			Slurpy[Item],     Item,
+			Slurpy[Ref],      Ref,
+			Slurpy[HashRef],  HashRef,
+			Slurpy[ArrayRef], ArrayRef;
+	}
+	( $_ == $type->{uniq} and return 1 ) for @uniqs;
+	return 0;
+}
+
 1;
 
 __END__
