@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Signature::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Signature::VERSION    = '2.007_010';
+	$Type::Params::Signature::VERSION    = '2.009_000';
 }
 
 $Type::Params::Signature::VERSION =~ tr/_//d;
@@ -775,6 +775,7 @@ sub _coderef_slurpy {
 		input_slot  => '$SLURPY',
 		display_var => '$SLURPY',
 		index       => 0,
+		is_slurpy   => 1,
 		$self->is_named
 			? ( output_slot => sprintf( '$out{%s}', B::perlstring( $parameter->name ) ) )
 			: ( output_var  => '@out' )
@@ -829,7 +830,7 @@ sub _coderef_end {
 	}
 
 	$self->_coderef_end_extra( $coderef );
-	$coderef->add_line( $self->_make_return_expression( is_early => 0 ) . ';' );
+	$coderef->add_line( $self->_make_return_expression( is_early => 0, allow_full_statements => 1 ) . ';' );
 	$coderef->{indent} =~ s/\t$//;
 	$coderef->add_line( '}' );
 
@@ -892,9 +893,13 @@ sub _make_return_expression {
 		elsif ( $list eq '@_' ) {
 			return sprintf 'goto( $__NEXT__ )';
 		}
+		elsif ( $args{allow_full_statements} and not ( $args{is_early} or not exists $args{is_early} ) ) {
+			# We are allowed to return full statements, not
+			# forced to use do {...} to make an expression.
+			return sprintf '@_ = ( %s ); goto $__NEXT__', $list;
+		}
 		else {
-			return sprintf 'do { @_ = ( %s ); goto $__NEXT__ }',
-				$list;
+			return sprintf 'do { @_ = ( %s ); goto $__NEXT__ }', $list;
 		}
 	}
 	elsif ( $args{is_early} or not exists $args{is_early} ) {
@@ -1083,6 +1088,8 @@ sub make_class_xs {
 		replace => 1,
 		%$attr,
 	);
+	
+	$self->make_extra_methods;
 }
 
 sub make_class_pp {
@@ -1093,6 +1100,8 @@ sub make_class_pp {
 		local $@;
 		eval( $code ) or die( $@ );
 	};
+	
+	$self->make_extra_methods;
 }
 
 sub make_class_pp_code {
@@ -1135,6 +1144,91 @@ sub make_class_pp_code {
 	return $coderef->code;
 }
 
+sub make_extra_methods {
+	my $self = shift;
+
+	my @parameters = @{ $self->parameters };
+	if ( $self->has_slurpy ) {
+		push @parameters, $self->slurpy;
+	}
+
+	my $coderef = $self->_new_code_accumulator;
+	$coderef->add_line( '{' );
+	$coderef->{indent} = "\t";
+	$coderef->add_line( sprintf( 'package %s;', $self->bless ) );
+	$coderef->add_line( 'use strict;' );
+	$coderef->add_line( 'no warnings;' );
+	
+	$coderef->add_line( 'my @FIELDS = (' );
+	for my $p ( @parameters ) {
+		$coderef->add_line( "\t" . B::perlstring( $p->name ) . "," )
+	}
+	$coderef->add_line( ');' );
+	
+	my @enum;
+	$coderef->add_line( 'my %FIELDS = (' );
+	for my $p ( @parameters ) {
+		$coderef->add_line( "\t" . B::perlstring( $p->name ) . " => "  . B::perlstring( $p->name ) . "," );
+		for my $p2 ( $p->_all_aliases($self) ) {
+			$coderef->add_line( "\t" . B::perlstring( $p2 ) . " => "  . B::perlstring( $p->name ) . "," );
+		}
+		push @enum, $p->name, $p->_all_aliases($self);
+	}
+	$coderef->add_line( ');' );
+	my $enum = ArrayRef[ Enum[ @enum ] ];
+	
+	$coderef->add_line( 'sub __TO_LIST__ {' );
+	$coderef->add_line( "\t" . 'my ( $arg, $fields ) = @_;' );
+	$coderef->add_line( "\t" . 'return map $arg->{$_}, @FIELDS if not defined $fields;' );
+	if ( ( defined $self->strictness and $self->strictness eq 1 ) or not $self->has_strictness ){
+		$coderef->add_line( "\t" . $enum->inline_assert( '$fields' ) );
+	}
+	elsif ( $self->strictness ) {
+		$coderef->add_line( "\t" . sprintf( 'if ( %s ) { %s }', $self->strictness, $enum->inline_assert( '$fields' ) ) );
+	}
+	$coderef->add_line( "\t" . 'return map $arg->{$FIELDS{$_}}, @$fields;' );
+	$coderef->add_line( '}' );
+
+	$coderef->add_line( 'sub __TO_ARRAYREF__ {' );
+	$coderef->add_line( "\t" . 'my ( $arg, $fields ) = @_;' );
+	$coderef->add_line( "\t" . 'return [ map $arg->{$_}, @FIELDS ] if not defined $fields;' );
+	if ( ( defined $self->strictness and $self->strictness eq 1 ) or not $self->has_strictness ){
+		$coderef->add_line( "\t" . $enum->inline_assert( '$fields' ) );
+	}
+	elsif ( $self->strictness ) {
+		$coderef->add_line( "\t" . sprintf( 'if ( %s ) { %s }', $self->strictness, $enum->inline_assert( '$fields' ) ) );
+	}
+	$coderef->add_line( "\t" . 'return [ map $arg->{$FIELDS{$_}}, @$fields ];' );
+	$coderef->add_line( '}' );
+
+	$coderef->add_line( 'sub __TO_HASHREF__ {' );
+	$coderef->add_line( "\t" . 'my ( $arg, $fields ) = @_;' );
+	$coderef->add_line( "\t" . 'return +{ map { ; $_ => $arg->{$_} } @FIELDS } if not defined $fields;' );
+	if ( ( defined $self->strictness and $self->strictness eq 1 ) or not $self->has_strictness ){
+		$coderef->add_line( "\t" . $enum->inline_assert( '$fields' ) );
+	}
+	elsif ( $self->strictness ) {
+		$coderef->add_line( "\t" . sprintf( 'if ( %s ) { %s }', $self->strictness, $enum->inline_assert( '$fields' ) ) );
+	}
+	$coderef->add_line( "\t" . 'return +{ map { ; $_ => $arg->{$FIELDS{$_}} } @$fields };' );
+	$coderef->add_line( '}' );
+	
+	$coderef->add_line( '1;' );
+	$coderef->{indent} = "";
+	$coderef->add_line( '}' );
+
+	my $code = $coderef->code;
+	local $@;
+	eval( $code ) or die( $@ );
+	
+	Type::Tiny::_install_overloads(
+		$self->bless,
+		'bool'          => sub { 1 },
+		'@{}'           => '__TO_ARRAYREF__',
+		'fallback'      => !!1,
+	);
+}
+
 sub return_wanted {
 	my $self = shift;
 	my $coderef = $self->coderef;
